@@ -2,7 +2,7 @@ from .application    import font_info, lining, imageText, screenshots, resize, t
 from .config         import create_config, modify_config, read_config
 from .options        import parseOpts, begin
 from .run            import run
-from .utils          import get_datadir, listToString, video_info, SIZE_UNIT, convert_unit, get_file_size, CheckIfFileExists, check_os, packagePath
+from .utils          import get_datadir, listToString, video_info, convert_unit, get_file_size, CheckIfFileExists, check_os, packagePath
 from .version        import *
 from .viewer         import deco, args_error, helps, configurations
 from .worker         import Generator
